==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cave/dialogs_cs.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Ten netopýr musí mít ale ukrutnou sílu.")


dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Hmm..., to jó.")


dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Ten červený tvor má trochu zvláštní tvar.")


dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Nestěžuj si. Něco mi říká, že se to bude ještě hodit.")


dialogId("jes-v-uzke", "font_big", "It`s too narrow for me. You have to do it on your own down there.")
dialogStr("Je to na mě úzké. Musíš to dole zvládnout sama.")


dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Ta bílá ryba tu neuvěřitelně překáží.")


dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("Ryba? Myslel jsem, že je to jen kámen.")


dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Zdá se mi, že grál bychom měli hledat úplně jinde...")


dialogId("jes-m-deprese", "font_small", "Don`t be depressive. We will solve this in no time.")
dialogStr("Nepropadej depresi. Tohle vyřešíme raz dva.")


dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("No nevím...")


dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("Tak vidíš, už jsi tu.")


dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("Co je to za opalizující potvoru?")


dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("To je ale nestvůra.")


dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("To je urážka Stvořitele.")


dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("To je kladivoun pableskující.")


dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("To je odporník lesklý.")


dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("To je hlavoun duhový.")


dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Ten netopýr je něčím zvláštní.")


dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("Je to netopýr flegmatik.")


dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("Je to netopýr vycpaný.")


dialogId("jes-v-netopyr1", "font_big", "It`s a sculpture of bat.")
dialogStr("Je to socha netopýra.")


dialogId("jes-m-netopyr2", "font_small", "It`s a stalagmite shaped as a bat.")
dialogStr("Je to krápník podobný netopýru.")


dialogId("jes-v-netopyr2", "font_big", "It`s a plain stalagmite.")
dialogStr("Je to obyčejný krápník.")


dialogId("jes-m-netopyr3", "font_small", "It`s just an ordinary piece of rock.")
dialogStr("Je to úplně obyčejný kus šutru.")


dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster`.")
dialogStr("Myslím, že tu 'potvoru` budeš potřebovat.")


dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination`.")
dialogStr("Myslím, že bys měla překonat nechuť k té 'nestvůře`.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cave/dialogs_cs.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Ten netopýr musí mít ale ukrutnou sílu.")


dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Hmm..., to jó.")


dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Ten červený tvor má trochu zvláštní tvar.")


dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Nestěžuj si. Něco mi říká, že se to bude ještě hodit.")


dialogId("jes-v-uzke", "font_big", "It’s too narrow for me. You have to do it on your own down there.")
dialogStr("Je to na mě úzké. Musíš to dole zvládnout sama.")


dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Ta bílá ryba tu neuvěřitelně překáží.")


dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("Ryba? Myslel jsem, že je to jen kámen.")


dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Zdá se mi, že grál bychom měli hledat úplně jinde...")


dialogId("jes-m-deprese", "font_small", "Don’t be depressive. We will solve this in no time.")
dialogStr("Nepropadej depresi. Tohle vyřešíme raz dva.")


dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("No nevím...")


dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("Tak vidíš, už jsi tu.")


dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("Co je to za opalizující potvoru?")


dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("To je ale nestvůra.")


dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("To je urážka Stvořitele.")


dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("To je kladivoun pableskující.")


dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("To je odporník lesklý.")


dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("To je hlavoun duhový.")


dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Ten netopýr je něčím zvláštní.")


dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("Je to netopýr flegmatik.")


dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("Je to netopýr vycpaný.")


dialogId("jes-v-netopyr1", "font_big", "It’s a sculpture of bat.")
dialogStr("Je to socha netopýra.")


dialogId("jes-m-netopyr2", "font_small", "It’s a stalagmite shaped as a bat.")
dialogStr("Je to krápník podobný netopýru.")


dialogId("jes-v-netopyr2", "font_big", "It’s a plain stalagmite.")
dialogStr("Je to obyčejný krápník.")


dialogId("jes-m-netopyr3", "font_small", "It’s just an ordinary piece of rock.")
dialogStr("Je to úplně obyčejný kus šutru.")


dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster’.")
dialogStr("Myslím, že tu 'potvoru’ budeš potřebovat.")


dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination’.")
dialogStr("Myslím, že bys měla překonat nechuť k té 'nestvůře’.")
